"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const inquirer_1 = require("inquirer");
const simple_git_1 = __importDefault(require("simple-git"));
const chalk_1 = __importDefault(require("chalk"));
(async function main() {
    const git = simple_git_1.default();
    const { all: branches, current: currentBranch } = await git.branch({
        '--sort': '-committerdate',
    });
    if (branches.length === 1) {
        throw new Error('You only have one branch');
    }
    if (branches.length === 0) {
        throw new Error('No branch found');
    }
    const mainBranch = branches.includes('main') ? 'main' : 'master';
    const { all: mergedBranches } = await git.branch(['--merged', mainBranch]);
    const { selectedBranches } = await inquirer_1.prompt({
        name: 'selectedBranches',
        type: 'checkbox',
        message: 'Select the branches to delete',
        choices: branches
            .filter((branch) => branch !== mainBranch)
            .map((branch) => ({
            name: mergedBranches.includes(branch)
                ? `${branch} ${chalk_1.default.gray.italic('merged')}`
                : branch,
            value: branch,
        })),
    });
    if (selectedBranches.includes(currentBranch)) {
        await git.checkout(mainBranch);
    }
    await git.deleteLocalBranches(selectedBranches, true);
})();
